if (getRversion() >= '2.15.1') globalVariables(c("NofAnimals", "NofLine", "N",
                                                 "ANOVArandom", "Coxrandom",
                                                 "PDOX lines", "Number of Animals"))
